@@ -11,7 +11,7 @@ learning training.
 from ._exponentiated_gradient import ExponentiatedGradient  # noqa: F401
 from ._grid_search import GridSearch  # noqa: F401
 from ._moments import AbsoluteLoss, Moment, ConditionalSelectionRate  # noqa: F401
-from ._moments import DemographicParity, EqualizedOdds, ErrorRate   # noqa: F401
+from ._moments import DemographicParity, EqualizedOdds, ErrorRateRatio, ErrorRate, TruePositiveRateDifference   # noqa: F401,E501
 from ._moments import GroupLossMoment, SquareLoss, ZeroOneLoss  # noqa: F401
 from ._moments import ClassificationMoment, LossMoment  # noqa: F401
 
@@ -30,6 +30,8 @@ _moments = [
     "ConditionalSelectionRate",
     "DemographicParity",
     "EqualizedOdds",
+    "TruePositiveRateDifference",
+    "ErrorRateRatio",
     "ErrorRate",
     "GroupLossMoment",
     "LossMoment",
