@@ -7,7 +7,7 @@ from .moment import Moment  # noqa: F401
 from .moment import ClassificationMoment, LossMoment  # noq: F401
 
 from .conditional_selection_rate import ConditionalSelectionRate  # noqa: F401
-from .conditional_selection_rate import DemographicParity, EqualizedOdds  # noqa: F401
+from .conditional_selection_rate import DemographicParity, EqualizedOdds, TruePositiveRateDifference, ErrorRateRatio  # noqa: F401,E501
 from .error_rate import ErrorRate   # noqa: F401
 from .bounded_group_loss import GroupLossMoment   # noqa: F401
 from .bounded_group_loss import SquareLoss, AbsoluteLoss, ZeroOneLoss  # noqa: F401
@@ -19,6 +19,8 @@ __all__ = [
     "ConditionalSelectionRate",
     "DemographicParity",
     "EqualizedOdds",
+    "TruePositiveRateDifference",
+    "ErrorRateRatio",
     "ErrorRate",
     "GroupLossMoment",
     "LossMoment",
